import React from 'react';
import { Award, Users, Globe, Heart, CheckCircle, Star, Trophy, AlignCenterVertical as Certificate } from 'lucide-react';
import LazyImage from './LazyImage';

interface AboutProps {
  language: 'az' | 'en' | 'ru';
}

const About: React.FC<AboutProps> = ({ language }) => {
  const content = {
    az: {
      badge: 'Uzman Həkim',
      title: 'Dr. Vüqar Ələkbərov',
      subtitle: 'Estetik, Plastik və Rekonstruktiv Cərrahiyyə Uzmanı',
      description: 'Dr. Vüqar Ələkbərov 10+ illik təcrübə ilə plastik və rekonstruktiv cərrahiyyə sahəsində xidmət göstərir. Beynəlxalq konqreslərdə iştirak edən, elmi işləri olan və 8000+ uğurlu əməliyyat həyata keçirən həkimimiz hər xəstəyə fərdi yanaşma tətbiq edir.',
      achievements: [
        'Azərbaycan Tibb Universitetini bitirib',
        'Türkiyədə ixtisaslaşma təhsili',
        'Beynəlxalq sertifikatlar',
        'Elmi məqalələr və tədqiqatlar'
      ],
      stats: [
        { number: '8000+', label: 'Uğurlu əməliyyat', icon: Award },
        { number: '10+', label: 'İl təcrübə', icon: Users },
        { number: '100%', label: 'Beynəlxalq standart', icon: Globe },
        { number: '5.0', label: 'Xəstə reytinqi', icon: Star }
      ],
      specialties: [
        'Rinoplastika və burun cərrahiyyəsi',
        'Mamoplastika və döş rekonstruksiyası',
        'Facelift və üz gəncləşdirmə',
        'Liposaksiya və bədən konturlaşdırması'
      ],
      cta: 'Konsultasiya üçün müraciət et'
    },
    en: {
      badge: 'Specialist Doctor',
      title: 'Dr. Vüqar Ələkbərov',
      subtitle: 'Specialist in Aesthetic, Plastic & Reconstructive Surgery',
      description: 'Dr. Vüqar Ələkbərov serves in the field of plastic and reconstructive surgery with 10+ years of experience. Our doctor, who participates in international congresses, has scientific works and has performed 8000+ successful operations, applies an individual approach to each patient.',
      achievements: [
        'Graduated from Azerbaijan Medical University',
        'Specialized training in Turkey',
        'International certifications',
        'Scientific articles and research'
      ],
      stats: [
        { number: '8000+', label: 'Successful operations', icon: Award },
        { number: '10+', label: 'Years experience', icon: Users },
        { number: '100%', label: 'International standard', icon: Globe },
        { number: '5.0', label: 'Patient rating', icon: Star }
      ],
      specialties: [
        'Rhinoplasty and nasal surgery',
        'Mammoplasty and breast reconstruction',
        'Facelift and facial rejuvenation',
        'Liposuction and body contouring'
      ],
      cta: 'Request Consultation'
    },
    ru: {
      badge: 'Врач-специалист',
      title: 'Др. Вугар Алекберов',
      subtitle: 'Специалист по эстетической, пластической и реконструктивной хирургии',
      description: 'Др. Вугар Алекберов работает в области пластической и реконструктивной хирургии с 10+ летним опытом. Наш врач, участвующий в международных конгрессах, имеющий научные работы и выполнивший 8000+ успешных операций, применяет индивидуальный подход к каждому пациенту.',
      achievements: [
        'Окончил Азербайджанский медицинский университет',
        'Специализированное обучение в Турции',
        'Международные сертификаты',
        'Научные статьи и исследования'
      ],
      stats: [
        { number: '8000+', label: 'Успешных операций', icon: Award },
        { number: '10+', label: 'Лет опыта', icon: Users },
        { number: '100%', label: 'Международный стандарт', icon: Globe },
        { number: '5.0', label: 'Рейтинг пациентов', icon: Star }
      ],
      specialties: [
        'Ринопластика и хирургия носа',
        'Маммопластика и реконструкция груди',
        'Фейслифт и омоложение лица',
        'Липосакция и контурирование тела'
      ],
      cta: 'Обратиться за консультацией'
    }
  };

  const scrollToContact = () => {
    const element = document.getElementById('contact');
    if (element) {
      element.scrollIntoView({ behavior: 'smooth' });
    }
  };

  return (
    <section id="about" className="py-24 bg-gradient-to-br from-gray-50 to-white">
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="grid lg:grid-cols-2 gap-16 items-center">
          {/* Left Content */}
          <div>
            {/* Professional Badge */}
            <div className="inline-flex items-center space-x-2 bg-blue-100 rounded-full px-6 py-3 mb-8">
              <Certificate className="w-5 h-5 text-blue-600" />
              <span className="text-blue-800 font-semibold">{content[language].badge}</span>
            </div>

            <h2 className="text-4xl md:text-5xl font-bold text-gray-900 mb-4">
              {content[language].title}
            </h2>
            <h3 className="text-2xl font-light text-blue-600 mb-8">
              {content[language].subtitle}
            </h3>
            <p className="text-lg text-gray-700 leading-relaxed mb-10">
              {content[language].description}
            </p>

            {/* Achievements */}
            <div className="mb-10">
              <h4 className="text-xl font-bold text-gray-900 mb-6">
                {language === 'az' ? 'Təhsil və Sertifikatlar' : language === 'en' ? 'Education & Certifications' : 'Образование и сертификаты'}
              </h4>
              <div className="space-y-4">
                {content[language].achievements.map((achievement, index) => (
                  <div key={index} className="flex items-center space-x-3">
                    <CheckCircle className="w-6 h-6 text-green-600 flex-shrink-0" />
                    <span className="text-gray-700 font-medium">{achievement}</span>
                  </div>
                ))}
              </div>
            </div>

            {/* Specialties */}
            <div className="mb-10">
              <h4 className="text-xl font-bold text-gray-900 mb-6">
                {language === 'az' ? 'İxtisas Sahələri' : language === 'en' ? 'Specialization Areas' : 'Области специализации'}
              </h4>
              <div className="grid grid-cols-1 gap-3">
                {content[language].specialties.map((specialty, index) => (
                  <div key={index} className="flex items-center space-x-3 bg-blue-50 rounded-lg p-4">
                    <Trophy className="w-5 h-5 text-blue-600 flex-shrink-0" />
                    <span className="text-gray-800 font-medium">{specialty}</span>
                  </div>
                ))}
              </div>
            </div>
            
            <button 
              onClick={scrollToContact}
              className="bg-gradient-to-r from-blue-600 to-blue-700 text-white px-8 py-4 rounded-xl hover:from-blue-700 hover:to-blue-800 transition-all duration-300 font-semibold text-lg hover:scale-105 shadow-xl"
            >
              {content[language].cta}
            </button>
          </div>

          {/* Right Image and Stats */}
          <div className="relative">
            {/* Main Image - Optimized for Core Web Vitals */}
            <div className="relative overflow-hidden rounded-3xl shadow-2xl">
              <LazyImage
                src="/v.jpg"
                alt="Dr. Vüqar Ələkbərov - Plastik Cərrah"
                className="w-full h-[700px] object-cover"
                fetchPriority="high"
              />
              <div className="absolute inset-0 bg-gradient-to-t from-black/30 via-transparent to-transparent"></div>
            </div>
            
            {/* Stats Grid */}
            <div className="grid grid-cols-2 gap-4 mt-8">
              {content[language].stats.map((stat, index) => {
                const IconComponent = stat.icon;
                return (
                  <div key={index} className="bg-white p-6 rounded-2xl shadow-lg hover:shadow-xl transition-all duration-300 border border-gray-100 hover:border-blue-200 group">
                    <div className="flex items-center space-x-3 mb-3">
                      <div className="w-12 h-12 bg-gradient-to-br from-blue-500 to-blue-600 rounded-xl flex items-center justify-center group-hover:scale-110 transition-transform duration-300">
                        <IconComponent className="w-6 h-6 text-white" />
                      </div>
                      <span className="text-3xl font-bold text-gray-900">{stat.number}</span>
                    </div>
                    <p className="text-gray-600 font-medium">{stat.label}</p>
                  </div>
                );
              })}
            </div>

            {/* Floating Achievement Card */}
            <div className="absolute -bottom-8 -left-8 bg-white p-6 rounded-2xl shadow-2xl border border-gray-100 max-w-xs">
              <div className="flex items-center space-x-4">
                <div className="w-16 h-16 bg-gradient-to-br from-yellow-400 to-yellow-500 rounded-full flex items-center justify-center">
                  <Trophy className="w-8 h-8 text-white" />
                </div>
                <div>
                  <p className="font-bold text-gray-900 text-lg">8000+</p>
                  <p className="text-sm text-gray-600 font-medium">
                    {language === 'az' ? 'Uğurlu əməliyyat' : language === 'en' ? 'Successful operations' : 'Успешных операций'}
                  </p>
                  <div className="flex items-center space-x-1 mt-1">
                    {[...Array(5)].map((_, i) => (
                      <Star key={i} className="w-3 h-3 text-yellow-400 fill-current" />
                    ))}
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default About;